/*-------------------- BEGIN globchem_cu_parameters.h BEGIN -------------------*/
/* @file globchem_cu_parameters.h                                              */
/* @author jlinford                                                            */
/* @date 2014-09-24 15:52:01.664438                                            */
/* @brief CUDA interface to program parameters                                 */
/*                                                                             */
/* CUDA interface to program parameters, such as integration tolerances,       */
/* program constants, and species indices.                                     */
/*                                                                             */
/* This file was generated by Kppa: http://www.paratools.com/Kppa              */
/*-----------------------------------------------------------------------------*/

#ifndef __GLOBCHEM_CU_PARAMETERS_H__
#define __GLOBCHEM_CU_PARAMETERS_H__



#ifdef __cplusplus
extern "C" {
#endif



/*-----------------------------------------------------------------------------*/
/* Integration tolerances                                                      */
/*-----------------------------------------------------------------------------*/

/* Absolute tolerance */
#define ATOLS            ((double)(1.0))
/* Relative tolerance */
#define RTOLS            ((double)(0.001))


/*-----------------------------------------------------------------------------*/
/* Concentration constants                                                     */
/*-----------------------------------------------------------------------------*/

/* Conversion factor */
#define CFACTOR          ((double)(1.0))
/* Default initialization value for variable species */
#define VAR_DEFAULT      ((double)(0.0))
/* Default initialization value for fixed species */
#define FIX_DEFAULT      ((double)(0.0))


/*-----------------------------------------------------------------------------*/
/* Program constants                                                           */
/*-----------------------------------------------------------------------------*/

/* Species count */
#define NSPEC            ((size_t)(184))
/* Variable species count */
#define NVAR             ((size_t)(174))
/* Fixed species count */
#define NFIX             ((size_t)(10))
/* Active variable species count */
#define NVARACT          ((size_t)(139))
/* Reaction (equation) count */
#define NREACT           ((size_t)(538))


/*-----------------------------------------------------------------------------*/
/* Numerical constants                                                         */
/*-----------------------------------------------------------------------------*/

#define ZERO             ((double)(0.0))
#define HALF             ((double)(0.5))
#define ONE              ((double)(1.0))
#define TWO              ((double)(2.0))


/*-----------------------------------------------------------------------------*/
/* Variable species indices                                                    */
/*-----------------------------------------------------------------------------*/

#define IND_DRYACET      ((size_t)(0))
#define IND_DRYCH2O      ((size_t)(1))
#define IND_DRYH2O2      ((size_t)(2))
#define IND_DRYHNO3      ((size_t)(3))
#define IND_DRYN2O5      ((size_t)(4))
#define IND_DRYNO2       ((size_t)(5))
#define IND_DRYO3        ((size_t)(6))
#define IND_DRYPAN       ((size_t)(7))
#define IND_DRYPMN       ((size_t)(8))
#define IND_DRYPMNN      ((size_t)(9))
#define IND_DRYPPN       ((size_t)(10))
#define IND_DRYR4N2      ((size_t)(11))
#define IND_DRYMVK       ((size_t)(12))
#define IND_DRYMACR      ((size_t)(13))
#define IND_DRYHAC       ((size_t)(14))
#define IND_DRYALD2      ((size_t)(15))
#define IND_MSA          ((size_t)(16))
#define IND_LISOPOH      ((size_t)(17))
#define IND_DRYHOBr      ((size_t)(18))
#define IND_DRYHBr       ((size_t)(19))
#define IND_DRYBrNO3     ((size_t)(20))
#define IND_DRYBr2       ((size_t)(21))
#define IND_PYAC         ((size_t)(22))
#define IND_DRYISOPND    ((size_t)(23))
#define IND_DRYISOPNB    ((size_t)(24))
#define IND_DRYRIP       ((size_t)(25))
#define IND_DRYIEPOX     ((size_t)(26))
#define IND_DRYMACRN     ((size_t)(27))
#define IND_DRYMVKN      ((size_t)(28))
#define IND_DRYPROPNN    ((size_t)(29))
#define IND_DRYHCOOH     ((size_t)(30))
#define IND_DRYACTA      ((size_t)(31))
#define IND_DRYHCl       ((size_t)(32))
#define IND_CO2          ((size_t)(33))
#define IND_DRYDEP       ((size_t)(34))
#define IND_CH3CCl3      ((size_t)(35))
#define IND_PPN          ((size_t)(36))
#define IND_SO4          ((size_t)(37))
#define IND_BrNO2        ((size_t)(38))
#define IND_IEPOX        ((size_t)(39))
#define IND_PMNN         ((size_t)(40))
#define IND_CCl4         ((size_t)(41))
#define IND_CFC11        ((size_t)(42))
#define IND_CFC12        ((size_t)(43))
#define IND_CFC113       ((size_t)(44))
#define IND_CFC114       ((size_t)(45))
#define IND_CFC115       ((size_t)(46))
#define IND_H1301        ((size_t)(47))
#define IND_H2402        ((size_t)(48))
#define IND_N2O          ((size_t)(49))
#define IND_H1211        ((size_t)(50))
#define IND_PAN          ((size_t)(51))
#define IND_OCS          ((size_t)(52))
#define IND_SO2          ((size_t)(53))
#define IND_N            ((size_t)(54))
#define IND_ALK4         ((size_t)(55))
#define IND_MAP          ((size_t)(56))
#define IND_CHBr3        ((size_t)(57))
#define IND_CH2Br2       ((size_t)(58))
#define IND_MPN          ((size_t)(59))
#define IND_Cl2O2        ((size_t)(60))
#define IND_RA3P         ((size_t)(61))
#define IND_RB3P         ((size_t)(62))
#define IND_DMS          ((size_t)(63))
#define IND_OClO         ((size_t)(64))
#define IND_ClNO2        ((size_t)(65))
#define IND_HCFC22       ((size_t)(66))
#define IND_HCFC123      ((size_t)(67))
#define IND_HCFC141b     ((size_t)(68))
#define IND_HCFC142b     ((size_t)(69))
#define IND_C3H8         ((size_t)(70))
#define IND_ETP          ((size_t)(71))
#define IND_HNO2         ((size_t)(72))
#define IND_CH3Br        ((size_t)(73))
#define IND_CH3Cl        ((size_t)(74))
#define IND_ClOO         ((size_t)(75))
#define IND_MP           ((size_t)(76))
#define IND_MAOP         ((size_t)(77))
#define IND_HNO4         ((size_t)(78))
#define IND_BrCl         ((size_t)(79))
#define IND_RP           ((size_t)(80))
#define IND_Br2          ((size_t)(81))
#define IND_ETHLN        ((size_t)(82))
#define IND_PRPN         ((size_t)(83))
#define IND_PP           ((size_t)(84))
#define IND_MRP          ((size_t)(85))
#define IND_R4P          ((size_t)(86))
#define IND_ATOOH        ((size_t)(87))
#define IND_RIP          ((size_t)(88))
#define IND_C2H6         ((size_t)(89))
#define IND_VRP          ((size_t)(90))
#define IND_IAP          ((size_t)(91))
#define IND_DHMOB        ((size_t)(92))
#define IND_MOBA         ((size_t)(93))
#define IND_N2O5         ((size_t)(94))
#define IND_INPN         ((size_t)(95))
#define IND_ISNP         ((size_t)(96))
#define IND_ISOPNB       ((size_t)(97))
#define IND_CH4          ((size_t)(98))
#define IND_H2O2         ((size_t)(99))
#define IND_IEPOXOO      ((size_t)(100))
#define IND_MACRNO2      ((size_t)(101))
#define IND_PMN          ((size_t)(102))
#define IND_MOBAOO       ((size_t)(103))
#define IND_ROH          ((size_t)(104))
#define IND_DIBOO        ((size_t)(105))
#define IND_PRPE         ((size_t)(106))
#define IND_MVKN         ((size_t)(107))
#define IND_BrNO3        ((size_t)(108))
#define IND_H            ((size_t)(109))
#define IND_Cl2          ((size_t)(110))
#define IND_ISNOHOO      ((size_t)(111))
#define IND_ISOP         ((size_t)(112))
#define IND_PROPNN       ((size_t)(113))
#define IND_ISNOOB       ((size_t)(114))
#define IND_HOBr         ((size_t)(115))
#define IND_A3O2         ((size_t)(116))
#define IND_CO           ((size_t)(117))
#define IND_GLYC         ((size_t)(118))
#define IND_MACRN        ((size_t)(119))
#define IND_MAOPO2       ((size_t)(120))
#define IND_ISOPND       ((size_t)(121))
#define IND_MRO2         ((size_t)(122))
#define IND_VRO2         ((size_t)(123))
#define IND_ACET         ((size_t)(124))
#define IND_HC5          ((size_t)(125))
#define IND_GLYX         ((size_t)(126))
#define IND_ISNOOA       ((size_t)(127))
#define IND_MAN2         ((size_t)(128))
#define IND_PRN1         ((size_t)(129))
#define IND_PO2          ((size_t)(130))
#define IND_MGLY         ((size_t)(131))
#define IND_B3O2         ((size_t)(132))
#define IND_ETO2         ((size_t)(133))
#define IND_RCO3         ((size_t)(134))
#define IND_ClNO3        ((size_t)(135))
#define IND_KO2          ((size_t)(136))
#define IND_R4N1         ((size_t)(137))
#define IND_HOCl         ((size_t)(138))
#define IND_ISN1         ((size_t)(139))
#define IND_HAC          ((size_t)(140))
#define IND_HNO3         ((size_t)(141))
#define IND_ATO2         ((size_t)(142))
#define IND_HC5OO        ((size_t)(143))
#define IND_MVK          ((size_t)(144))
#define IND_RIO2         ((size_t)(145))
#define IND_MAO3         ((size_t)(146))
#define IND_INO2         ((size_t)(147))
#define IND_MACR         ((size_t)(148))
#define IND_ISOPNBO2     ((size_t)(149))
#define IND_ISOPNDO2     ((size_t)(150))
#define IND_R4O2         ((size_t)(151))
#define IND_RCHO         ((size_t)(152))
#define IND_MEK          ((size_t)(153))
#define IND_R4N2         ((size_t)(154))
#define IND_MCO3         ((size_t)(155))
#define IND_ALD2         ((size_t)(156))
#define IND_CH2O         ((size_t)(157))
#define IND_MO2          ((size_t)(158))
#define IND_NO           ((size_t)(159))
#define IND_H2O          ((size_t)(160))
#define IND_HO2          ((size_t)(161))
#define IND_NO2          ((size_t)(162))
#define IND_Br           ((size_t)(163))
#define IND_HCl          ((size_t)(164))
#define IND_ClO          ((size_t)(165))
#define IND_HBr          ((size_t)(166))
#define IND_Cl           ((size_t)(167))
#define IND_O3           ((size_t)(168))
#define IND_BrO          ((size_t)(169))
#define IND_NO3          ((size_t)(170))
#define IND_O1D          ((size_t)(171))
#define IND_OH           ((size_t)(172))
#define IND_O            ((size_t)(173))


/*-----------------------------------------------------------------------------*/
/* Fixed species indices                                                       */
/*-----------------------------------------------------------------------------*/

#define IND_ACTA         ((size_t)(174))
#define IND_EMISSION     ((size_t)(175))
#define IND_EOH          ((size_t)(176))
#define IND_H2           ((size_t)(177))
#define IND_HCOOH        ((size_t)(178))
#define IND_MOH          ((size_t)(179))
#define IND_N2           ((size_t)(180))
#define IND_O2           ((size_t)(181))
#define IND_RCOOH        ((size_t)(182))
#define IND_KPP_DUMMY    ((size_t)(183))



#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* __GLOBCHEM_CU_PARAMETERS_H__ */
/*---------------------- END globchem_cu_parameters.h END ---------------------*/
