!-------------------- BEGIN globchem_parameters.f90 BEGIN --------------------
! @file globchem_parameters.f90                                               
! @author jlinford                                                            
! @date 2014-09-23 12:57:26.783580                                            
! @brief Program parameters                                                   
!                                                                             
! Integration tolerances, program constants, and species indices.             
!                                                                             
! This file was generated by Kppa: http://www.paratools.com/Kppa              
!-----------------------------------------------------------------------------


MODULE globchem_parameters


  IMPLICIT NONE



!-----------------------------------------------------------------------------
! Integration tolerances                                                      
!-----------------------------------------------------------------------------

  ! Absolute tolerance 
  REAL(8), PARAMETER :: ATOLS = 1.d-2
  ! Relative tolerance 
  REAL(8), PARAMETER :: RTOLS = 2.d-2


!-----------------------------------------------------------------------------
! Concentration constants                                                     
!-----------------------------------------------------------------------------

  ! Conversion factor 
  REAL(8), PARAMETER :: CFACTOR = 1.0
  ! Default initialization value for variable species 
  REAL(8), PARAMETER :: VAR_DEFAULT = 0.0
  ! Default initialization value for fixed species 
  REAL(8), PARAMETER :: FIX_DEFAULT = 0.0


!-----------------------------------------------------------------------------
! Program constants                                                           
!-----------------------------------------------------------------------------

  ! Species count 
  INTEGER, PARAMETER :: NSPEC = 184
  ! Variable species count 
  INTEGER, PARAMETER :: NVAR = 174
  ! Fixed species count 
  INTEGER, PARAMETER :: NFIX = 10
  ! Active variable species count 
  INTEGER, PARAMETER :: NVARACT = 139
  ! Reaction (equation) count 
  INTEGER, PARAMETER :: NREACT = 538


!-----------------------------------------------------------------------------
! Numerical constants                                                         
!-----------------------------------------------------------------------------

  REAL(8), PARAMETER :: ZERO = 0.0
  REAL(8), PARAMETER :: HALF = 0.5
  REAL(8), PARAMETER :: ONE = 1.0
  REAL(8), PARAMETER :: TWO = 2.0


!-----------------------------------------------------------------------------
! Variable species indices                                                    
!-----------------------------------------------------------------------------

  INTEGER, PARAMETER :: IND_DRYACET = 1
  INTEGER, PARAMETER :: IND_DRYCH2O = 2
  INTEGER, PARAMETER :: IND_DRYH2O2 = 3
  INTEGER, PARAMETER :: IND_DRYHNO3 = 4
  INTEGER, PARAMETER :: IND_DRYN2O5 = 5
  INTEGER, PARAMETER :: IND_DRYNO2 = 6
  INTEGER, PARAMETER :: IND_DRYO3 = 7
  INTEGER, PARAMETER :: IND_DRYPAN = 8
  INTEGER, PARAMETER :: IND_DRYPMN = 9
  INTEGER, PARAMETER :: IND_DRYPMNN = 10
  INTEGER, PARAMETER :: IND_DRYPPN = 11
  INTEGER, PARAMETER :: IND_DRYR4N2 = 12
  INTEGER, PARAMETER :: IND_DRYMVK = 13
  INTEGER, PARAMETER :: IND_DRYMACR = 14
  INTEGER, PARAMETER :: IND_DRYHAC = 15
  INTEGER, PARAMETER :: IND_DRYALD2 = 16
  INTEGER, PARAMETER :: IND_MSA = 17
  INTEGER, PARAMETER :: IND_LISOPOH = 18
  INTEGER, PARAMETER :: IND_DRYHOBr = 19
  INTEGER, PARAMETER :: IND_DRYHBr = 20
  INTEGER, PARAMETER :: IND_DRYBrNO3 = 21
  INTEGER, PARAMETER :: IND_DRYBr2 = 22
  INTEGER, PARAMETER :: IND_PYAC = 23
  INTEGER, PARAMETER :: IND_DRYISOPND = 24
  INTEGER, PARAMETER :: IND_DRYISOPNB = 25
  INTEGER, PARAMETER :: IND_DRYRIP = 26
  INTEGER, PARAMETER :: IND_DRYIEPOX = 27
  INTEGER, PARAMETER :: IND_DRYMACRN = 28
  INTEGER, PARAMETER :: IND_DRYMVKN = 29
  INTEGER, PARAMETER :: IND_DRYPROPNN = 30
  INTEGER, PARAMETER :: IND_DRYHCOOH = 31
  INTEGER, PARAMETER :: IND_DRYACTA = 32
  INTEGER, PARAMETER :: IND_DRYHCl = 33
  INTEGER, PARAMETER :: IND_CO2 = 34
  INTEGER, PARAMETER :: IND_DRYDEP = 35
  INTEGER, PARAMETER :: IND_CH3CCl3 = 36
  INTEGER, PARAMETER :: IND_PPN = 37
  INTEGER, PARAMETER :: IND_SO4 = 38
  INTEGER, PARAMETER :: IND_BrNO2 = 39
  INTEGER, PARAMETER :: IND_IEPOX = 40
  INTEGER, PARAMETER :: IND_PMNN = 41
  INTEGER, PARAMETER :: IND_CCl4 = 42
  INTEGER, PARAMETER :: IND_CFC11 = 43
  INTEGER, PARAMETER :: IND_CFC12 = 44
  INTEGER, PARAMETER :: IND_CFC113 = 45
  INTEGER, PARAMETER :: IND_CFC114 = 46
  INTEGER, PARAMETER :: IND_CFC115 = 47
  INTEGER, PARAMETER :: IND_H1301 = 48
  INTEGER, PARAMETER :: IND_H2402 = 49
  INTEGER, PARAMETER :: IND_N2O = 50
  INTEGER, PARAMETER :: IND_H1211 = 51
  INTEGER, PARAMETER :: IND_PAN = 52
  INTEGER, PARAMETER :: IND_OCS = 53
  INTEGER, PARAMETER :: IND_SO2 = 54
  INTEGER, PARAMETER :: IND_N = 55
  INTEGER, PARAMETER :: IND_ALK4 = 56
  INTEGER, PARAMETER :: IND_MAP = 57
  INTEGER, PARAMETER :: IND_CHBr3 = 58
  INTEGER, PARAMETER :: IND_CH2Br2 = 59
  INTEGER, PARAMETER :: IND_MPN = 60
  INTEGER, PARAMETER :: IND_Cl2O2 = 61
  INTEGER, PARAMETER :: IND_RA3P = 62
  INTEGER, PARAMETER :: IND_RB3P = 63
  INTEGER, PARAMETER :: IND_DMS = 64
  INTEGER, PARAMETER :: IND_OClO = 65
  INTEGER, PARAMETER :: IND_ClNO2 = 66
  INTEGER, PARAMETER :: IND_HCFC22 = 67
  INTEGER, PARAMETER :: IND_HCFC123 = 68
  INTEGER, PARAMETER :: IND_HCFC141b = 69
  INTEGER, PARAMETER :: IND_HCFC142b = 70
  INTEGER, PARAMETER :: IND_C3H8 = 71
  INTEGER, PARAMETER :: IND_ETP = 72
  INTEGER, PARAMETER :: IND_HNO2 = 73
  INTEGER, PARAMETER :: IND_CH3Br = 74
  INTEGER, PARAMETER :: IND_CH3Cl = 75
  INTEGER, PARAMETER :: IND_ClOO = 76
  INTEGER, PARAMETER :: IND_MP = 77
  INTEGER, PARAMETER :: IND_MAOP = 78
  INTEGER, PARAMETER :: IND_HNO4 = 79
  INTEGER, PARAMETER :: IND_BrCl = 80
  INTEGER, PARAMETER :: IND_RP = 81
  INTEGER, PARAMETER :: IND_Br2 = 82
  INTEGER, PARAMETER :: IND_ETHLN = 83
  INTEGER, PARAMETER :: IND_PRPN = 84
  INTEGER, PARAMETER :: IND_PP = 85
  INTEGER, PARAMETER :: IND_MRP = 86
  INTEGER, PARAMETER :: IND_R4P = 87
  INTEGER, PARAMETER :: IND_ATOOH = 88
  INTEGER, PARAMETER :: IND_RIP = 89
  INTEGER, PARAMETER :: IND_C2H6 = 90
  INTEGER, PARAMETER :: IND_VRP = 91
  INTEGER, PARAMETER :: IND_IAP = 92
  INTEGER, PARAMETER :: IND_DHMOB = 93
  INTEGER, PARAMETER :: IND_MOBA = 94
  INTEGER, PARAMETER :: IND_N2O5 = 95
  INTEGER, PARAMETER :: IND_INPN = 96
  INTEGER, PARAMETER :: IND_ISNP = 97
  INTEGER, PARAMETER :: IND_ISOPNB = 98
  INTEGER, PARAMETER :: IND_CH4 = 99
  INTEGER, PARAMETER :: IND_H2O2 = 100
  INTEGER, PARAMETER :: IND_IEPOXOO = 101
  INTEGER, PARAMETER :: IND_MACRNO2 = 102
  INTEGER, PARAMETER :: IND_PMN = 103
  INTEGER, PARAMETER :: IND_MOBAOO = 104
  INTEGER, PARAMETER :: IND_ROH = 105
  INTEGER, PARAMETER :: IND_DIBOO = 106
  INTEGER, PARAMETER :: IND_PRPE = 107
  INTEGER, PARAMETER :: IND_MVKN = 108
  INTEGER, PARAMETER :: IND_BrNO3 = 109
  INTEGER, PARAMETER :: IND_H = 110
  INTEGER, PARAMETER :: IND_Cl2 = 111
  INTEGER, PARAMETER :: IND_ISNOHOO = 112
  INTEGER, PARAMETER :: IND_ISOP = 113
  INTEGER, PARAMETER :: IND_PROPNN = 114
  INTEGER, PARAMETER :: IND_ISNOOB = 115
  INTEGER, PARAMETER :: IND_HOBr = 116
  INTEGER, PARAMETER :: IND_A3O2 = 117
  INTEGER, PARAMETER :: IND_CO = 118
  INTEGER, PARAMETER :: IND_GLYC = 119
  INTEGER, PARAMETER :: IND_MACRN = 120
  INTEGER, PARAMETER :: IND_MAOPO2 = 121
  INTEGER, PARAMETER :: IND_ISOPND = 122
  INTEGER, PARAMETER :: IND_MRO2 = 123
  INTEGER, PARAMETER :: IND_VRO2 = 124
  INTEGER, PARAMETER :: IND_ACET = 125
  INTEGER, PARAMETER :: IND_HC5 = 126
  INTEGER, PARAMETER :: IND_GLYX = 127
  INTEGER, PARAMETER :: IND_ISNOOA = 128
  INTEGER, PARAMETER :: IND_MAN2 = 129
  INTEGER, PARAMETER :: IND_PRN1 = 130
  INTEGER, PARAMETER :: IND_PO2 = 131
  INTEGER, PARAMETER :: IND_MGLY = 132
  INTEGER, PARAMETER :: IND_B3O2 = 133
  INTEGER, PARAMETER :: IND_ETO2 = 134
  INTEGER, PARAMETER :: IND_RCO3 = 135
  INTEGER, PARAMETER :: IND_ClNO3 = 136
  INTEGER, PARAMETER :: IND_KO2 = 137
  INTEGER, PARAMETER :: IND_R4N1 = 138
  INTEGER, PARAMETER :: IND_HOCl = 139
  INTEGER, PARAMETER :: IND_ISN1 = 140
  INTEGER, PARAMETER :: IND_HAC = 141
  INTEGER, PARAMETER :: IND_HNO3 = 142
  INTEGER, PARAMETER :: IND_ATO2 = 143
  INTEGER, PARAMETER :: IND_HC5OO = 144
  INTEGER, PARAMETER :: IND_MVK = 145
  INTEGER, PARAMETER :: IND_RIO2 = 146
  INTEGER, PARAMETER :: IND_MAO3 = 147
  INTEGER, PARAMETER :: IND_INO2 = 148
  INTEGER, PARAMETER :: IND_MACR = 149
  INTEGER, PARAMETER :: IND_ISOPNBO2 = 150
  INTEGER, PARAMETER :: IND_ISOPNDO2 = 151
  INTEGER, PARAMETER :: IND_R4O2 = 152
  INTEGER, PARAMETER :: IND_RCHO = 153
  INTEGER, PARAMETER :: IND_MEK = 154
  INTEGER, PARAMETER :: IND_R4N2 = 155
  INTEGER, PARAMETER :: IND_MCO3 = 156
  INTEGER, PARAMETER :: IND_ALD2 = 157
  INTEGER, PARAMETER :: IND_CH2O = 158
  INTEGER, PARAMETER :: IND_MO2 = 159
  INTEGER, PARAMETER :: IND_NO = 160
  INTEGER, PARAMETER :: IND_H2O = 161
  INTEGER, PARAMETER :: IND_HO2 = 162
  INTEGER, PARAMETER :: IND_NO2 = 163
  INTEGER, PARAMETER :: IND_Br = 164
  INTEGER, PARAMETER :: IND_HCl = 165
  INTEGER, PARAMETER :: IND_ClO = 166
  INTEGER, PARAMETER :: IND_HBr = 167
  INTEGER, PARAMETER :: IND_Cl = 168
  INTEGER, PARAMETER :: IND_O3 = 169
  INTEGER, PARAMETER :: IND_BrO = 170
  INTEGER, PARAMETER :: IND_NO3 = 171
  INTEGER, PARAMETER :: IND_O1D = 172
  INTEGER, PARAMETER :: IND_OH = 173
  INTEGER, PARAMETER :: IND_O = 174


!-----------------------------------------------------------------------------
! Fixed species indices                                                       
!-----------------------------------------------------------------------------

  INTEGER, PARAMETER :: IND_ACTA = 175
  INTEGER, PARAMETER :: IND_EMISSION = 176
  INTEGER, PARAMETER :: IND_EOH = 177
  INTEGER, PARAMETER :: IND_H2 = 178
  INTEGER, PARAMETER :: IND_HCOOH = 179
  INTEGER, PARAMETER :: IND_MOH = 180
  INTEGER, PARAMETER :: IND_N2 = 181
  INTEGER, PARAMETER :: IND_O2 = 182
  INTEGER, PARAMETER :: IND_RCOOH = 183
  INTEGER, PARAMETER :: IND_KPP_DUMMY = 184


END MODULE globchem_parameters
!---------------------- END globchem_parameters.f90 END ----------------------
